@@ -20,6 +20,8 @@ wave_no is short for wavenumber
 import os.path
 import sqlite3
 from typing import Tuple
+
+import simpletrans.plank
 from simpletrans import isa
 import numpy as np
 import pandas as pd
@@ -240,6 +242,25 @@ class AtmosphereGrid:
         wave_no_grid = self.ones_grid * self.wave_no_bins.transpose()
         return plank_nu(wave_no_grid, temp_grid, flux=True).transpose()
 
+    def surface_flux(self) -> pd.DataFrame:
+        """
+        Returns an array of spectral radiance as a function of flux.
+        Returns:
+            Dataframe of spectral Radiance.
+        """
+        ground_temp = simpletrans.isa.get_temperature(0)
+        ground_flux = simpletrans.plank.plank_nu(self.wave_no_bins,
+                                                       ground_temp
+                                                       )
+        transmission_grid = np.exp(-self.od_df)
+        # Transmission
+        for i, alt in enumerate(self.alt_list):
+            if i != 0:
+                transmission_grid.iloc[:, i] \
+                    *= transmission_grid.iloc[:, i-1]
+        (transmission_grid.T * ground_flux).T
+
+
     def flux_up(self) -> pd.DataFrame:
         """
         Calculates the total flux from the blackbody emission from both,
@@ -248,26 +269,12 @@ class AtmosphereGrid:
         Returns:
 
         """
-        ground_flux = plank_nu(
-            self.wave_no_bins, isa.get_temperature(self.alt_min), flux=True
-        )
-        transmission_all_alt = np.exp(-self.od_df)
-        blackbody_grid = self.get_blackbody_grid()
-        # Initialise the transmission functions
-
-        transmission_from_surf = transmission_all_alt
-
-        flux_from_ith_block = transmission_all_alt * blackbody_grid
-        # wavenumber grid has spacing 1 cm^(-1) such that no
-        # multiplication is needed
-        for i, _ in enumerate(flux_from_ith_block.iloc[0, :]):
-            if i != 0:
-                if i != 1:
-                    flux_from_ith_block.iloc[:, i - 1] \
-                        += flux_from_ith_block.iloc[:, i - 2]
-                transmission_from_surf.iloc[:, i] \
-                    *= transmission_from_surf.iloc[:, i - 1]
-        flux_from_surf = (transmission_from_surf.transpose() * ground_flux).transpose()
-        total_flux = flux_from_surf+ flux_from_ith_block + self.get_blackbody_grid()
-        return pd.DataFrame(total_flux, columns=self.od_df.columns)
-
+        ground_temp = simpletrans.isa.get_temperature(0)
+        ground_flux = simpletrans.plank.plank_nu(self.wave_no_bins,
+                                                 ground_temp,
+                                                 flux=True
+                                                 )
+        transmission_grid = np.exp(-self.od_df)
+        flux_from_ground = (transmission_grid.T * ground_flux).T
+        atm_flux = transmission_grid * self.get_blackbody_grid() - self.get_blackbody_grid()
+        return flux_from_ground - atm_flux
\ No newline at end of file
